@@ -15,30 +15,25 @@
  * @category   Zend
  * @package    Zend
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: AllTests.php 20729 2010-01-28 21:53:19Z thomas $
  */
 
+require_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'TestHelper.php';
+
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'AllTests::main');
 }
 
-/**
- * Test helper
- */
-require_once 'TestHelper.php';
-
-/**
- * @see Zend_AllTests
- */
 require_once 'Zend/AllTests.php';
+require_once 'resources/AllTests.php';
 
 /**
  * @category   Zend
  * @package    Zend
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class AllTests
@@ -95,6 +90,7 @@ class AllTests
         $suite = new PHPUnit_Framework_TestSuite('Zend Framework');
 
         $suite->addTest(Zend_AllTests::suite());
+        $suite->addTest(resources_AllTests::suite());
 
         return $suite;
     }
