@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestHelper.php 17363 2009-08-03 07:40:18Z bkarwin $
+ * @version    $Id: TestHelper.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 /*
@@ -40,17 +40,10 @@ error_reporting( E_ALL | E_STRICT );
  * Determine the root, library, and tests directories of the framework
  * distribution.
  */
-$zfRoot        = dirname(__FILE__) . '/..';
+$zfRoot        = realpath(dirname(dirname(__FILE__)));
 $zfCoreLibrary = "$zfRoot/library";
 $zfCoreTests   = "$zfRoot/tests";
 
-/*
- * Omit from code coverage reports the contents of the tests directory
- */
-foreach (array('php', 'phtml', 'csv') as $suffix) {
-    PHPUnit_Util_Filter::addDirectoryToFilter($zfCoreTests, ".$suffix");
-}
-
 /*
  * Prepend the Zend Framework library/ and tests/ directories to the
  * include_path. This allows the tests to run out of the box and helps prevent
@@ -74,6 +67,28 @@ if (is_readable($zfCoreTests . DIRECTORY_SEPARATOR . 'TestConfiguration.php')) {
     require_once $zfCoreTests . DIRECTORY_SEPARATOR . 'TestConfiguration.php.dist';
 }
 
+if (defined('TESTS_GENERATE_REPORT') && TESTS_GENERATE_REPORT === true &&
+    version_compare(PHPUnit_Runner_Version::id(), '3.1.6', '>=')) {
+
+    /*
+     * Add Zend Framework library/ directory to the PHPUnit code coverage
+     * whitelist. This has the effect that only production code source files
+     * appear in the code coverage report and that all production code source
+     * files, even those that are not covered by a test yet, are processed.
+     */
+    PHPUnit_Util_Filter::addDirectoryToWhitelist($zfCoreLibrary);
+
+    /*
+     * Omit from code coverage reports the contents of the tests directory
+     */
+    foreach (array('.php', '.phtml', '.csv', '.inc') as $suffix) {
+        PHPUnit_Util_Filter::addDirectoryToFilter($zfCoreTests, $suffix);
+    }
+    PHPUnit_Util_Filter::addDirectoryToFilter(PEAR_INSTALL_DIR);
+    PHPUnit_Util_Filter::addDirectoryToFilter(PHP_LIBDIR);
+}
+
+
 /**
  * Start output buffering, if enabled
  */
@@ -81,17 +96,6 @@ if (defined('TESTS_ZEND_OB_ENABLED') && constant('TESTS_ZEND_OB_ENABLED')) {
     ob_start();
 }
 
-/*
- * Add Zend Framework library/ directory to the PHPUnit code coverage
- * whitelist. This has the effect that only production code source files appear
- * in the code coverage report and that all production code source files, even
- * those that are not covered by a test yet, are processed.
- */
-if (defined('TESTS_GENERATE_REPORT') && TESTS_GENERATE_REPORT === true &&
-    version_compare(PHPUnit_Runner_Version::id(), '3.1.6', '>=')) {
-    PHPUnit_Util_Filter::addDirectoryToWhitelist($zfCoreLibrary);
-}
-
 /*
  * Unset global variables that are no longer needed.
  */
