@@ -15,42 +15,24 @@
  * @category   Zend
  * @package    Zend_Acl
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AclTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: AclTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
+require_once dirname(dirname(dirname(__FILE__))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
 
-/**
- * Zend_Acl
- */
 require_once 'Zend/Acl.php';
-
-/**
- * Zend_Acl_Resource
- */
 require_once 'Zend/Acl/Resource.php';
-
-/**
- * Zend_Acl_Role
- */
 require_once 'Zend/Acl/Role.php';
-
-/**
- * @see Zend_Acl_MockAssertion
- */
 require_once dirname(__FILE__) . '/_files/MockAssertion.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Acl
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @group      Zend_Acl
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Acl_AclTest extends PHPUnit_Framework_TestCase
@@ -1200,12 +1182,14 @@ class Zend_Acl_AclTest extends PHPUnit_Framework_TestCase
 
     /**
      * Returns an array of registered roles
+     * @expectedException PHPUnit_Framework_Error
      * @issue ZF-5638
      */
     public function testGetRegisteredRoles()
     {
         $acl = $this->_acl;
         $acl->addRole('developer');
+
         $roles = $acl->getRegisteredRoles();
         $this->assertTrue(is_array($roles));
         $this->assertFalse(empty($roles));
@@ -1233,4 +1217,88 @@ class Zend_Acl_AclTest extends PHPUnit_Framework_TestCase
         // Check after fix
         $this->assertFalse($acl->hasRole('test0'));
     }
+
+    /**
+     * @group ZF-8039
+     *
+     * Meant to test for the (in)existance of this notice:
+     * "Notice: Undefined index: allPrivileges in lib/Zend/Acl.php on line 682"
+     */
+    public function testMethodRemoveAllowDoesNotThrowNotice() {
+        $acl = new Zend_Acl();
+        $acl->addRole('admin');
+        $acl->addResource('blog');
+        $acl->allow('admin', 'blog', 'read');
+        $acl->removeAllow(array('admin'), array('blog'), null);
+    }
+
+    public function testRoleObjectImplementsToString() {
+        $role = new Zend_Acl_Role('_fooBar_');
+        $this->assertEquals('_fooBar_',(string)$role);
+    }
+
+    public function testResourceObjectImplementsToString() {
+        $resource = new Zend_Acl_Resource('_fooBar_');
+        $this->assertEquals('_fooBar_',(string)$resource);
+    }
+
+    /**
+     * @group ZF-7973
+     */
+    public function testAclPassesPrivilegeToAssertClass() {
+        require_once dirname(__FILE__) . '/_files/AssertionZF7973.php';
+        $assertion = new Zend_Acl_AclTest_AssertionZF7973();
+
+        $acl = new Zend_Acl();
+        $acl->addRole('role');
+        $acl->addResource('resource');
+        $acl->allow('role',null,null,$assertion);
+        $allowed = $acl->isAllowed('role','resource','privilege',$assertion);
+
+        $this->assertTrue($allowed);
+    }
+    
+    /**
+     * @group ZF-8468
+     */
+    public function testGetRegisteredRolesIsDeprecated() {
+        try {
+            $this->_acl->getRegisteredRoles();
+            $this->fail('getRegisteredRoles() did not throw an exception');
+        } catch(PHPUnit_Framework_Error $e) {
+            return;
+        }
+        
+        $this->fail('An expected notice has not been raised');
+    }
+    
+    /**
+     * @group ZF-8468
+     */
+    public function testgetRoles() {
+        $this->assertEquals(array(),$this->_acl->getRoles());
+
+        $roleGuest = new Zend_Acl_Role('guest');
+        $this->_acl->addRole($roleGuest);
+        $this->_acl->addRole(new Zend_Acl_Role('staff'), $roleGuest);
+        $this->_acl->addRole(new Zend_Acl_Role('editor'), 'staff');
+        $this->_acl->addRole(new Zend_Acl_Role('administrator'));
+
+        $expected = array('guest', 'staff','editor','administrator');
+        $this->assertEquals($expected, $this->_acl->getRoles());
+    }
+    
+    /**
+     * @group ZF-8468
+     */
+    public function testgetResources() {
+        $this->assertEquals(array(),$this->_acl->getResources());
+
+        $this->_acl->add(new Zend_Acl_Resource('someResource'));
+        $this->_acl->add(new Zend_Acl_Resource('someOtherResource'));
+
+        $expected = array('someResource', 'someOtherResource');
+        $this->assertEquals($expected, $this->_acl->getResources());
+    }
+
 }
