@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Amf
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id$
+ * @version    $Id: ResourceTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 // Call Zend_Amf_AuthTest::main() if this source file is executed directly.
@@ -36,7 +36,7 @@ require_once 'Zend/Amf/Value/Messaging/RemotingMessage.php';
  * @category   Zend
  * @package    Zend_Amf
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Amf
  */
@@ -153,11 +153,11 @@ class Zend_Amf_Resource_testclass {
     function returnCtx()
     {
         $opts = array(
-              'http'=>array(
+            'http'=>array(
             'method'=>"GET",
             'header'=>"Accept-language: en\r\n" .
-                  "Cookie: foo=bar\r\n"
-              )
+                "Cookie: foo=bar\r\n"
+            )
         );
         $context = stream_context_create($opts);
         return $context;
@@ -166,14 +166,16 @@ class Zend_Amf_Resource_testclass {
 
 class StreamContext2
 {
-    public function parse($resource) {
-               return stream_context_get_options($resource);
+    public function parse($resource)
+    {
+        return stream_context_get_options($resource);
     }
 }
 class StreamContext3
 {
-    protected function parse($resource) {
-               return stream_context_get_options($resource);
+    protected function parse($resource)
+    {
+        return stream_context_get_options($resource);
     }
 }
 class Zend_Amf_TestResourceLoader implements Zend_Loader_PluginLoader_Interface {
@@ -193,3 +195,4 @@ class Zend_Amf_TestResourceLoader implements Zend_Loader_PluginLoader_Interface
 if (PHPUnit_MAIN_METHOD == "Zend_Amf_ResourceTest::main") {
     Zend_Amf_ResourceTest::main();
 }
+
