@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Application
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: BootstrapAbstractTest.php 19313 2009-11-30 13:56:36Z bate $
+ * @version    $Id: BootstrapAbstractTest.php 20988 2010-02-08 16:44:44Z matthew $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -63,7 +63,7 @@ require_once 'Zend/Application/Bootstrap/Bootstrap.php';
  * @category   Zend
  * @package    Zend_Application
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Application
  */
@@ -719,6 +719,16 @@ class Zend_Application_Bootstrap_BootstrapAbstractTest extends PHPUnit_Framework
         $actual   = $bootstrap->getOptionKeys();
         $this->assertEquals($expected, $actual);
     }
+
+    /**
+     * @group ZF-9110
+     * @expectedException Zend_Application_Bootstrap_Exception
+     */
+    public function testPassingSameBootstrapAsApplicationShouldNotCauseRecursion()
+    {
+        $bootstrap = new Zend_Application_Bootstrap_Bootstrap($this->application);
+        $bootstrap->setApplication($bootstrap);
+    }
 }
 
 class Zend_Application_Bootstrap_BootstrapAbstractTest_View
