@@ -15,48 +15,27 @@
  * @category   Zend
  * @package    Zend_Auth
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: AllTests.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
+require_once dirname(dirname(dirname(dirname(dirname(__FILE__))))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Auth_Adapter_DbTable_AllTests::main');
 }
 
-
-/**
- * PHPUnit_Framework_TestSuite
- */
-require_once 'PHPUnit/Framework/TestSuite.php';
-
-
-/**
- * PHPUnit_TextUI_TestRunner
- */
-require_once 'PHPUnit/TextUI/TestRunner.php';
-
-
-/**
- * @see Zend_Auth_Adapter_DbTable_BasicSqliteTest
- */
 require_once 'Zend/Auth/Adapter/DbTable/BasicSqliteTest.php';
-
-
-/**
- * @see Zend_Auth_Adapter_DbTable_BasicSqliteTest_SkipTests
- */
 require_once 'Zend/Auth/Adapter/DbTable/BasicSqliteTest/SkipTests.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Auth
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
- * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Auth
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Auth_Adapter_DbTable_AllTests
 {
@@ -77,24 +56,24 @@ class Zend_Auth_Adapter_DbTable_AllTests
      */
     public static function suite()
     {
-        $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Zend_Auth_Adapter_Http');
+        $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Zend_Auth_Adapter_DbTable');
 
         if (!defined('TESTS_ZEND_AUTH_ADAPTER_DBTABLE_PDO_SQLITE_ENABLED') ||
             constant('TESTS_ZEND_AUTH_ADAPTER_DBTABLE_PDO_SQLITE_ENABLED') === false) {
-        $skipTest = new Zend_Auth_Adapter_DbTable_BasicSqliteTest_SkipTests();
-        $skipTest->message = 'Tests are not enabled in TestConfiguration.php';
+	    $skipTest = new Zend_Auth_Adapter_DbTable_BasicSqliteTest_SkipTests();
+	    $skipTest->message = 'Tests are not enabled in TestConfiguration.php';
             $suite->addTest($skipTest);
         } else if (!extension_loaded('pdo')) {
-        $skipTest = new Zend_Auth_Adapter_DbTable_BasicSqliteTest_SkipTests();
-        $skipTest->message = "Extension 'PDO' is not loaded";
+	    $skipTest = new Zend_Auth_Adapter_DbTable_BasicSqliteTest_SkipTests();
+	    $skipTest->message = "Extension 'PDO' is not loaded";
             $suite->addTest($skipTest);
         } else if (!in_array('sqlite', PDO::getAvailableDrivers())) {
-        $skipTest = new Zend_Auth_Adapter_DbTable_BasicSqliteTest_SkipTests();
-        $skipTest->message = "PDO driver 'sqlite' is not available";
+	    $skipTest = new Zend_Auth_Adapter_DbTable_BasicSqliteTest_SkipTests();
+	    $skipTest->message = "PDO driver 'sqlite' is not available";
             $suite->addTest($skipTest);
         } else {
             $suite->addTestSuite('Zend_Auth_Adapter_DbTable_BasicSqliteTest');
-    }
+	}
 
         return $suite;
     }
