@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Cache
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: CommonExtendedBackendTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: CommonExtendedBackendTest.php 21535 2010-03-17 18:20:53Z mabe $
  */
 
 require_once 'PHPUnit/Util/Filter.php';
@@ -38,7 +38,7 @@ require_once 'CommonBackendTest.php';
  * @category   Zend
  * @package    Zend_Cache
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Cache
  */
@@ -65,6 +65,17 @@ class Zend_Cache_CommonExtendedBackendTest extends Zend_Cache_CommonBackendTest
         $this->assertTrue($res <= 100);
     }
 
+    public function testGetFillingPercentageOnEmptyBackend()
+    {
+        $this->_instance->setDirectives(array('logging' => false)); // ???
+        $this->_instance->clean(Zend_Cache::CLEANING_MODE_ALL);
+        $res = $this->_instance->getFillingPercentage();
+        $this->_instance->setDirectives(array('logging' => true)); // ???
+        $this->assertTrue(is_integer($res));
+        $this->assertTrue($res >= 0);
+        $this->assertTrue($res <= 100);
+    }
+
     public function testGetIds()
     {
         if (!($this->_capabilities['get_list'])) {
