@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_CodeGenerator
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id $
  */
@@ -33,7 +33,7 @@ require_once 'Zend/Reflection/Class.php';
  * @category   Zend
  * @package    Zend_CodeGenerator
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  *
  * @group Zend_CodeGenerator
@@ -88,7 +88,10 @@ EOS;
             'defaultValue' => $targetValue
             ));
 
-        $this->assertEquals($expectedSource, $property->generate());
+        $targetSource = $property->generate();
+        $targetSource = str_replace("\r", '', $targetSource);
+            
+        $this->assertEquals($expectedSource, $targetSource);
     }
 
     public function testPropertyCanProduceContstantModifier()
