@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: IniTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: IniTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 /**
@@ -34,7 +34,7 @@ require_once 'Zend/Config/Ini.php';
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Config
  */
@@ -268,6 +268,26 @@ class Zend_Config_IniTest extends PHPUnit_Framework_TestCase
         }
 
     }
+    
+    /**
+     * @group ZF-8159
+     */
+    public function testZF8159()
+    {
+        $config = new Zend_Config_Ini(
+            dirname(__FILE__) . '/_files/zf8159.ini',
+            array('first', 'second')
+        );
+        
+        $this->assertTrue(isset(
+           $config->user->login->elements->password
+        ));
+        
+        $this->assertEquals(
+            'password',
+            $config->user->login->elements->password->type
+        );
+    }
 
     /*
      * @group ZF-5800
@@ -281,4 +301,17 @@ class Zend_Config_IniTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('1', $config->receiver->{0}->html);
         $this->assertNull($config->receiver->mail);
     }
+    
+    /*
+     * @group ZF-6508
+     */
+    public function testPreservationOfIntegerKeys()
+    {
+        $filename = dirname(__FILE__) . '/_files/zf6508.ini';
+        $config = new Zend_Config_Ini($filename, 'all');
+        $this->assertEquals(true, isset($config->{1002}));
+        
+    }
+    
+
 }
