@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: IniTest.php 19737 2009-12-18 01:52:18Z dasprid $
+ * @version    $Id: IniTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 /**
@@ -44,7 +44,7 @@ require_once 'Zend/Config/Writer/Ini.php';
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Config
  */
@@ -164,6 +164,76 @@ class Zend_Config_Writer_IniTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('foo', $config->default->test);
     }
 
+    /**
+     * @group ZF-8234
+     */
+    public function testRender()
+    {
+        $config = new Zend_Config(array('test' => 'foo', 'bar' => array(0 => 'baz', 1 => 'foo')));
+
+        $writer = new Zend_Config_Writer_Ini();
+        $iniString = $writer->setConfig($config)->render();
+
+        $expected = <<<ECS
+test = "foo"
+[bar]
+0 = "baz"
+1 = "foo"
+
+
+ECS;
+        $this->assertEquals($expected, $iniString);
+    }
+
+    public function testRenderWithoutSections()
+    {
+        $config = new Zend_Config(array('test' => 'foo', 'test2' => array('test3' => 'bar')));
+
+        $writer = new Zend_Config_Writer_Ini();
+        $writer->setRenderWithoutSections();
+        $iniString = $writer->setConfig($config)->render();
+
+        $expected = <<<ECS
+test = "foo"
+test2.test3 = "bar"
+
+ECS;
+        $this->assertEquals($expected, $iniString);
+    }
+
+    public function testRenderWithoutSections2()
+    {
+        $config = new Zend_Config_Ini(dirname(__FILE__) . '/files/allsections.ini', null, array('skipExtends' => true));
+
+        $writer = new Zend_Config_Writer_Ini();
+        $writer->setRenderWithoutSections();
+        $iniString = $writer->setConfig($config)->render();
+
+        $expected = <<<ECS
+all.hostname = "all"
+all.name = "thisname"
+all.db.host = "127.0.0.1"
+all.db.user = "username"
+all.db.pass = "password"
+all.db.name = "live"
+all.one.two.three = "multi"
+staging.hostname = "staging"
+staging.db.name = "dbstaging"
+staging.debug = ""
+debug.hostname = "debug"
+debug.debug = "1"
+debug.values.changed = "1"
+debug.db.name = "dbdebug"
+debug.special.no = ""
+debug.special.null = ""
+debug.special.false = ""
+other_staging.only_in = "otherStaging"
+other_staging.db.pass = "anotherpwd"
+
+ECS;
+        $this->assertEquals($expected, $iniString);
+    }
+
     public function testZF6521_NoDoubleQuoutesInValue()
     {
         $config = new Zend_Config(array('default' => array('test' => 'fo"o')));
