@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: XmlTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: XmlTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 /**
@@ -44,7 +44,7 @@ require_once 'Zend/Config/Writer/Xml.php';
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Config
  */
@@ -151,6 +151,28 @@ class Zend_Config_Writer_XmlTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(null, @$config->production);
     }
 
+    /**
+     * @group ZF-6773
+     */
+    public function testWriteMultidimensionalArrayWithNumericKeys()
+    {
+        $writer = new Zend_Config_Writer_Xml;
+        $writer->write($this->_tempName, new Zend_Config(array(
+            'notification' => array(
+                'adress' => array(
+                    0 => array(
+                        'name' => 'Matthew',
+                        'mail' => 'matthew@example.com'
+                    ),
+                    1 => array(
+                        'name' => 'Thomas',
+                        'mail' => 'thomas@example.com'
+                    )
+                )
+            )
+        )));
+    }
+
     public function testNumericArray()
     {
         $config = new Zend_Config(array('foo' => array('bar' => array(1 => 'a', 2 => 'b', 5 => 'c'))));
@@ -189,4 +211,27 @@ class Zend_Config_Writer_XmlTest extends PHPUnit_Framework_TestCase
 
         $this->assertEquals('foo', $config->default->test);
     }
+
+    /**
+     * @group ZF-8234
+     */
+    public function testRender()
+    {
+        $config = new Zend_Config(array('test' => 'foo', 'bar' => array(0 => 'baz', 1 => 'foo')));
+
+        $writer = new Zend_Config_Writer_Xml();
+        $configString = $writer->setConfig($config)->render();
+
+        $expected = <<<ECS
+<?xml version="1.0"?>
+<zend-config xmlns:zf="http://framework.zend.com/xml/zend-config-xml/1.0/">
+  <test>foo</test>
+  <bar>baz</bar>
+  <bar>foo</bar>
+</zend-config>
+
+ECS;
+
+        $this->assertEquals($expected, $configString);
+    }
 }
