@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: RewriteTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: RewriteTest.php 20246 2010-01-12 21:36:08Z dasprid $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -59,7 +59,7 @@ require_once 'PHPUnit/Runner/Version.php';
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Router
@@ -263,10 +263,15 @@ class Zend_Controller_Router_RewriteTest extends PHPUnit_Framework_TestCase
 
         $this->_router->addRoute('default', new Zend_Controller_Router_Route(':controller/:action'));
 
-        $token = $this->_router->route($request);
+        try {
+            $token = $this->_router->route($request);
+            $this->fail('An expected Zend_Controller_Router_Exception was not raised');
+        } catch (Zend_Controller_Router_Exception $expected) {
+            $this->assertEquals('No route matched the request', $expected->getMessage());
+        }
 
-        $this->assertNull($token->getControllerName());
-        $this->assertNull($token->getActionName());
+        $this->assertNull($request->getControllerName());
+        $this->assertNull($request->getActionName());
     }
 
     public function testDefaultRouteMatched()
@@ -381,7 +386,12 @@ class Zend_Controller_Router_RewriteTest extends PHPUnit_Framework_TestCase
         $request = new Zend_Controller_Router_RewriteTest_Request('http://localhost/ctrl/act');
         $this->_router->removeDefaultRoutes();
 
-        $token = $this->_router->route($request);
+        try {
+            $token = $this->_router->route($request);
+            $this->fail('An expected Zend_Controller_Router_Exception was not raised');
+        } catch (Zend_Controller_Router_Exception $expected) {
+            $this->assertEquals('No route matched the request', $expected->getMessage());
+        }
 
         $routes = $this->_router->getRoutes();
         $this->assertEquals(0, count($routes));
@@ -700,6 +710,28 @@ class Zend_Controller_Router_RewriteTest extends PHPUnit_Framework_TestCase
         $url = $this->_router->assemble(array(),'chains_separator_bar');
         $this->assertEquals('/foo/bar',$url);
     }
+
+    public function testRequestParamsUsedAsGlobalParam()
+    {
+        $route = new Zend_Controller_Router_Route(
+            '/articles/:id',
+            array(
+                'controller' => 'blog',
+                'action'     => 'articles',
+            )
+        );
+
+        $request = Zend_Controller_Front::getInstance()->getRequest();
+        $request->setParam('id', 777);
+
+        $this->_router->addRoute('article-id', $route);
+        $this->_router->useRequestParametersAsGlobal(true);
+        $this->_router->route($request);
+
+        $url = $this->_router->assemble(array(), 'article-id');
+
+        $this->assertEquals('/articles/777', $url);
+    }
 }
 
 
