@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: RegexTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: RegexTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 require_once dirname(__FILE__) . '/../../../../TestHelper.php';
@@ -29,7 +29,7 @@ require_once 'Zend/Controller/Router/Route/Regex.php';
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Router
@@ -466,4 +466,45 @@ class Zend_Controller_Router_Route_RegexTest extends PHPUnit_Framework_TestCase
         $this->assertEquals($url, $expectedUrl, 'Assembled url isn\'t encoded properly when using the encode parameter.');
     }
 
+    /**
+     * Allow using <lang>1</lang> instead of invalid <1>lang</1> for xml router
+     * config.
+     *
+     * <zend-config>
+     *     <routes>
+     *         <page>
+     *             <type>Zend_Controller_Router_Route_Regex</type>
+     *             <route>([a-z]{2})/page/(.*)</route>
+     *             <defaults>
+     *                 <controller>index</controller>
+     *                 <action>showpage</action>
+     *             </defaults>
+     *             <map>
+     *                 <lang>1</lang>
+     *                 <title>2</title>
+     *             </map>
+     *             <reverse>%s/page/%s</reverse>
+     *         </page>
+     *     </routes>
+     * </zend-config>
+     *
+     *
+     * @group ZF-7658
+     */
+    public function testAssembleWithFlippedMappedVariables()
+    {
+        $route = new Zend_Controller_Router_Route_Regex(
+            '([a-z]{2})/page/(.*)',
+            array('controller' => 'index', 'action' => 'showpage'),
+            array('lang' => 1, 'title' => 2),
+            '%s/page/%s'
+        );
+
+        $url = $route->assemble(array(
+            'lang'  => 'fi',
+            'title' => 'Suomi'
+        ), true, true);
+
+        $this->assertEquals($url, 'fi/page/Suomi');
+    }
 }
