@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: RouteTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: RouteTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 /**
@@ -48,7 +48,7 @@ require_once 'PHPUnit/Framework/TestCase.php';
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Router
@@ -441,6 +441,24 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('archives/2006/03', $url);
     }
 
+    /**
+     * @group ZF-7917
+     */
+    public function testAssembleWithGivenDataEqualsDefaults()
+    {
+        $route = new Zend_Controller_Router_Route('index/*', array(
+            'module'     => 'default',
+            'controller' => 'index',
+            'action'     => 'index'
+        ));
+
+        $this->assertEquals('index', $route->assemble(array(
+            'module'     => 'default',
+            'controller' => 'index',
+            'action'     => 'index'
+        )));
+    }
+
     public function testWildcardUrlVariablesOverwriting()
     {
         $route = new Zend_Controller_Router_Route('archives/:year/:month/*', array('controller' => 'archive'));
