@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id $
  */
@@ -28,7 +28,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__);
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Db
  * @group      Zend_Db_Adapter
@@ -185,7 +185,7 @@ class Zend_Db_Adapter_Pdo_PgsqlTest extends Zend_Db_Adapter_Pdo_TestCommon
     /**
      * @group ZF-3972
      */
-    public function testCharacterVarying()
+    public function testAdapterCharacterVarying()
     {
         $this->_util->createTable('zf_pgsql_charvary',
                                   array('pg_id' => 'character varying(4) NOT NULL',
@@ -195,4 +195,16 @@ class Zend_Db_Adapter_Pdo_PgsqlTest extends Zend_Db_Adapter_Pdo_TestCommon
         $this->assertEquals(null , $description['pg_id']['DEFAULT']);
         $this->assertEquals('A', $description['pg_info']['DEFAULT']);
     }
+
+    /**
+     * @group ZF-7640
+     */
+    public function testAdapterBpchar()
+    {
+        $this->_util->createTable('zf_pgsql_bpchar',
+                                  array('pg_name' => "character(100) DEFAULT 'Default'::bpchar"));
+        $description = $this->_db->describeTable('zf_pgsql_bpchar');
+        $this->_util->dropTable('zf_pgsql_bpchar');
+        $this->assertEquals('Default', $description['pg_name']['DEFAULT']);
+    }
 }
