@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: TestCommon.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 
@@ -34,7 +34,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__);
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
@@ -1609,6 +1609,24 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
         $this->assertEquals(1, $result[0]['id']);
     }
 
+    /**
+     * @group ZF-4772
+     * @expectedException Zend_Db_Select_Exception
+     */
+    public function testSelectUnionNoArrayThrowsException()
+    {
+        $this->_db->select()->union('string');
+    }
+
+    /**
+     * @group ZF-4772
+     * @expectedException Zend_Db_Select_Exception
+     */
+    public function testSelectUnionInvalidUnionTypeThrowsException()
+    {
+        $this->_db->select()->union(array(), 'foo');
+    }
+
     /**
      * @group ZF-6653
      */
@@ -1654,9 +1672,9 @@ abstract class Zend_Db_Select_TestCommon extends Zend_Db_TestSetup
     {
         $select = $this->_selectWithMultipleFromsAfterAJoinWillProperlyOrderColumns();
         $quote = $this->_db->getQuoteIdentifierSymbol();
-        $target = 'SELECT `f`.`columnfoo`, `d`.`columndoo`, `b`.`barcolumn` AS `baralias` FROM `foo` AS `f`'
-            . "\n" . ' INNER JOIN `doo` AS `d`'
-            . "\n" . ' LEFT JOIN `bar` AS `b` ON f.columnfoo2 = b.barcolumn2';
+        $target = 'SELECT `f`.`columnfoo`, `d`.`columndoo`, `b`.`barcolumn` AS `baralias` FROM ' . $this->_db->quoteTableAs('foo', 'f')
+            . "\n" . ' INNER JOIN ' . $this->_db->quoteTableAs('doo', 'd')
+            . "\n" . ' LEFT JOIN ' . $this->_db->quoteTableAs('bar', 'b') . ' ON f.columnfoo2 = b.barcolumn2';
         if ($quote != '`') {
             $target = str_replace('`', $quote, $target);
         }
