@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: TestCommon.php 21079 2010-02-18 18:15:49Z tech13 $
  */
 
 
@@ -43,7 +43,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__);
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 abstract class Zend_Db_Table_TestCommon extends Zend_Db_Table_TestSetup
@@ -691,7 +691,7 @@ abstract class Zend_Db_Table_TestCommon extends Zend_Db_Table_TestSetup
         );
 
         $profilerEnabled = $this->_db->getProfiler()->getEnabled();
-        $this->_db->getProfiler()->setEnabled(true);
+        $this->_db->getProfiler()->setEnabled(true)->setFilterQueryType(Zend_Db_Profiler::INSERT);
         $insertResult = $table->insert($row);
         $this->_db->getProfiler()->setEnabled($profilerEnabled);
 
@@ -1304,9 +1304,9 @@ abstract class Zend_Db_Table_TestCommon extends Zend_Db_Table_TestSetup
         try {
             $bugsTable = $this->_getTable('My_ZendDbTable_TableBugs');
             $primary = $bugsTable->info(Zend_Db_Table_Abstract::PRIMARY);
-            $this->fail('Expected to catch Zend_Db_Table_Exception');
-        } catch (Zend_Exception $e) {
-            $this->assertType('Zend_Db_Table_Exception', $e);
+            $this->fail('Expected to catch PHPUnit_Framework_Error');
+        } catch (PHPUnit_Framework_Error $e) {
+            $this->assertEquals(E_USER_NOTICE, $e->getCode(), 'Error type not E_USER_NOTICE');
             $this->assertEquals('Failed saving metadata to metadataCache', $e->getMessage());
         }
 
@@ -1614,6 +1614,28 @@ abstract class Zend_Db_Table_TestCommon extends Zend_Db_Table_TestSetup
         return $cacheFrontend;
     }
 
+    /**
+     * @group ZF-5674
+     */
+    public function testTableAndIdentityWithVeryLongName()
+    {
+        Zend_Db_Table::setDefaultAdapter($this->_db);
+        // create test table using no identifier quoting
+        $this->_util->createTable('thisisaveryverylongtablename', array(
+            'thisisalongtablenameidentity' => 'IDENTITY',
+            'stuff' => 'VARCHAR(32)'
+        ));
+        $tableName = $this->_util->getTableName('thisisaveryverylongtablename');
+        $table = new Zend_Db_Table('thisisaveryverylongtablename');
+        $row = $table->createRow($this->_getRowForTableAndIdentityWithVeryLongName());
+        $row->save();
+        $rowset = $table->find(1);
+        $this->assertEquals(1, count($rowset));
+        $this->_util->dropTable('thisisaveryverylongtablename');
+    }
 
-
+    protected function _getRowForTableAndIdentityWithVeryLongName()
+    {
+        return array('stuff' => 'information');
+    }
 }
