@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Dojo
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: QueryTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: QueryTest.php 21157 2010-02-23 17:52:15Z matthew $
  */
 
 // Call Zend_Dom_QueryTest::main() if this source file is executed directly.
@@ -36,7 +36,7 @@ require_once 'Zend/Dom/Query.php';
  * @category   Zend
  * @package    Zend_Dom
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Dom
  */
@@ -89,6 +89,11 @@ class Zend_Dom_QueryTest extends PHPUnit_Framework_TestCase
         $this->query->setDocument($this->getHtml());
     }
 
+    public function handleError($msg, $code = 0) 
+    {
+        $this->error = $msg;
+    }
+
     public function testConstructorShouldNotRequireArguments()
     {
         $query = new Zend_Dom_Query();
@@ -154,11 +159,14 @@ class Zend_Dom_QueryTest extends PHPUnit_Framework_TestCase
 
     public function testQueryingInvalidDocumentShouldThrowException()
     {
+        set_error_handler(array($this, 'handleError'));
         $this->query->setDocumentXml('some bogus string');
         try {
             $this->query->query('.foo');
+            restore_error_handler();
             $this->fail('Querying invalid document should throw exception');
         } catch (Zend_Dom_Exception $e) {
+            restore_error_handler();
             $this->assertContains('Error parsing', $e->getMessage());
         }
     }
@@ -222,6 +230,19 @@ class Zend_Dom_QueryTest extends PHPUnit_Framework_TestCase
         $result = $this->query->queryXpath('//li[contains(@dojotype, "bar")]');
         $this->assertEquals(2, count($result), $result->getXpathQuery());
     }
+
+    /**
+     * @group ZF-9243
+     */
+    public function testLoadingDocumentWithErrorsShouldNotRaisePhpErrors()
+    {
+        $file = file_get_contents(dirname(__FILE__) . '/_files/bad-sample.html');
+        $this->query->setDocument($file);
+        $this->query->query('p');
+        $errors = $this->query->getDocumentErrors();
+        $this->assertTrue(is_array($errors));
+        $this->assertTrue(0 < count($errors));
+    }
 }
 
 // Call Zend_Dom_QueryTest::main() if this source file is executed directly.
