@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Feed
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AtomTest.php 19103 2009-11-20 16:54:07Z padraic $
+ * @version    $Id: AtomTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 require_once 'PHPUnit/Framework/TestCase.php';
@@ -27,7 +27,7 @@ require_once 'Zend/Feed/Reader.php';
  * @category   Zend
  * @package    Zend_Feed
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Feed
  * @group      Zend_Feed_Reader
@@ -38,9 +38,14 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
     protected $_feedSamplePath = null;
     
     protected $_options = array();
+    
+    protected $_expectedCats = array();
+    
+    protected $_expectedCatsDc = array();
 
     public function setup()
     {
+        Zend_Feed_Reader::reset();
         if (Zend_Registry::isRegistered('Zend_Locale')) {
             $registry = Zend_Registry::getInstance();
             unset($registry['Zend_Locale']);
@@ -53,6 +58,35 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
             }
         }
         Zend_Date::setOptions(array('format_type'=>'iso'));
+        $this->_expectedCats = array(
+            array(
+                'term' => 'topic1',
+                'scheme' => 'http://example.com/schema1',
+                'label' => 'topic1'
+            ),
+            array(
+                'term' => 'topic1',
+                'scheme' => 'http://example.com/schema2',
+                'label' => 'topic1'
+            ),
+            array(
+                'term' => 'cat_dog',
+                'scheme' => 'http://example.com/schema1',
+                'label' => 'Cat & Dog'
+            )
+        );
+        $this->_expectedCatsDc = array(
+            array(
+                'term' => 'topic1',
+                'scheme' => null,
+                'label' => 'topic1'
+            ),
+            array(
+                'term' => 'topic2',
+                'scheme' => null,
+                'label' => 'topic2'
+            )
+        );
     }
     
     public function teardown()
@@ -89,14 +123,15 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
         );
 
         $authors = array(
-            0 => 'joe@example.com (Joe Bloggs)',
-            1 => 'Joe Bloggs',
-            3 => 'joe@example.com',
-            4 => 'http://www.example.com',
-            6 => 'jane@example.com (Jane Bloggs)'
+            array('email'=>'joe@example.com','name'=>'Joe Bloggs','uri'=>'http://www.example.com'),
+            array('name'=>'Joe Bloggs','uri'=>'http://www.example.com'),
+            array('name'=>'Joe Bloggs'),
+            array('email'=>'joe@example.com','uri'=>'http://www.example.com'),
+            array('uri'=>'http://www.example.com'),
+            array('email'=>'joe@example.com')
         );
 
-        $this->assertEquals($authors, $feed->getAuthors());
+        $this->assertEquals($authors, (array) $feed->getAuthors());
     }
 
     public function testGetsAuthorArrayFromAtom10()
@@ -106,14 +141,15 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
         );
 
         $authors = array(
-            0 => 'joe@example.com (Joe Bloggs)',
-            1 => 'Joe Bloggs',
-            3 => 'joe@example.com',
-            4 => 'http://www.example.com',
-            6 => 'jane@example.com (Jane Bloggs)'
+            array('email'=>'joe@example.com','name'=>'Joe Bloggs','uri'=>'http://www.example.com'),
+            array('name'=>'Joe Bloggs','uri'=>'http://www.example.com'),
+            array('name'=>'Joe Bloggs'),
+            array('email'=>'joe@example.com','uri'=>'http://www.example.com'),
+            array('uri'=>'http://www.example.com'),
+            array('email'=>'joe@example.com')
         );
 
-        $this->assertEquals($authors, $feed->getAuthors());
+        $this->assertEquals($authors, (array) $feed->getAuthors());
     }
 
     /**
@@ -125,7 +161,7 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
             file_get_contents($this->_feedSamplePath.'/author/plain/atom03.xml')
         );
 
-        $this->assertEquals('joe@example.com (Joe Bloggs)', $feed->getAuthor());
+        $this->assertEquals(array('name'=>'Joe Bloggs','email'=>'joe@example.com','uri'=>'http://www.example.com'), $feed->getAuthor());
     }
 
     public function testGetsSingleAuthorFromAtom10()
@@ -134,7 +170,7 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
             file_get_contents($this->_feedSamplePath.'/author/plain/atom10.xml')
         );
 
-        $this->assertEquals('joe@example.com (Joe Bloggs)', $feed->getAuthor());
+        $this->assertEquals(array('name'=>'Joe Bloggs','email'=>'joe@example.com','uri'=>'http://www.example.com'), $feed->getAuthor());
     }
 
     /**
@@ -354,6 +390,31 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('http://www.example.com/feed/atom', $feed->getFeedLink());
     }
 
+    /**
+     * Get Pubsubhubbub Hubs
+     */
+    public function testGetsHubsFromAtom03()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/hubs/plain/atom03.xml')
+        );
+        $this->assertEquals(array(
+            'http://www.example.com/hub1',
+            'http://www.example.com/hub2'
+        ), $feed->getHubs());
+    }
+
+    public function testGetsHubsFromAtom10()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/hubs/plain/atom10.xml')
+        );
+        $this->assertEquals(array(
+            'http://www.example.com/hub1',
+            'http://www.example.com/hub2'
+        ), $feed->getHubs());
+    }
+
 
     /**
      * Implements Countable
@@ -366,4 +427,68 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
         );
         $this->assertEquals(0, count($feed));
     }
+    
+    /**
+     * Get category data
+     */
+    
+    // Atom 1.0 (Atom 0.3 never supported categories except via Atom 1.0/Dublin Core extensions)
+    
+    public function testGetsCategoriesFromAtom10()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/category/plain/atom10.xml')
+        );
+        $this->assertEquals($this->_expectedCats, (array) $feed->getCategories());
+        $this->assertEquals(array('topic1','Cat & Dog'), array_values($feed->getCategories()->getValues()));
+    }
+    
+    public function testGetsCategoriesFromAtom03_Atom10Extension()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/category/plain/atom03.xml')
+        );
+        $this->assertEquals($this->_expectedCats, (array) $feed->getCategories());
+        $this->assertEquals(array('topic1','Cat & Dog'), array_values($feed->getCategories()->getValues()));
+    }
+    
+    // DC 1.0/1.1 for Atom 0.3
+    
+    public function testGetsCategoriesFromAtom03_Dc10()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/category/plain/dc10/atom03.xml')
+        );
+        $this->assertEquals($this->_expectedCatsDc, (array) $feed->getCategories());
+        $this->assertEquals(array('topic1','topic2'), array_values($feed->getCategories()->getValues()));
+    }
+    
+    public function testGetsCategoriesFromAtom03_Dc11()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/category/plain/dc11/atom03.xml')
+        );
+        $this->assertEquals($this->_expectedCatsDc, (array) $feed->getCategories());
+        $this->assertEquals(array('topic1','topic2'), array_values($feed->getCategories()->getValues()));
+    }
+    
+    // No Categories In Entry
+    
+    public function testGetsCategoriesFromAtom10_None()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/category/plain/none/atom10.xml')
+        );
+        $this->assertEquals(array(), (array) $feed->getCategories());
+        $this->assertEquals(array(), array_values($feed->getCategories()->getValues()));
+    }
+    
+    public function testGetsCategoriesFromAtom03_None()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/category/plain/none/atom03.xml')
+        );
+        $this->assertEquals(array(), (array) $feed->getCategories());
+        $this->assertEquals(array(), array_values($feed->getCategories()->getValues()));
+    }
 }
