@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Feed
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id:$
+ * @version    $Id: H-OnlineComAtom10Test.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 require_once 'PHPUnit/Framework/TestCase.php';
@@ -27,7 +27,7 @@ require_once 'Zend/Feed/Reader.php';
  * @category   Zend
  * @package    Zend_Feed
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Feed
  * @group      Zend_Feed_Reader
@@ -39,6 +39,7 @@ class Zend_Feed_Reader_Integration_HOnlineComAtom10Test extends PHPUnit_Framewor
 
     public function setup()
     {
+        Zend_Feed_Reader::reset();
         $this->_feedSamplePath = dirname(__FILE__) . '/_files/h-online.com-atom10.xml';
         $this->_options = Zend_Date::setOptions();
         foreach($this->_options as $k=>$v) {
@@ -67,7 +68,7 @@ class Zend_Feed_Reader_Integration_HOnlineComAtom10Test extends PHPUnit_Framewor
         $feed = Zend_Feed_Reader::importString(
             file_get_contents($this->_feedSamplePath)
         );
-        $this->assertEquals(array('The H'), $feed->getAuthors());
+        $this->assertEquals(array(array('name'=>'The H')), (array) $feed->getAuthors());
     }
 
     public function testGetsSingleAuthor()
@@ -75,7 +76,7 @@ class Zend_Feed_Reader_Integration_HOnlineComAtom10Test extends PHPUnit_Framewor
         $feed = Zend_Feed_Reader::importString(
             file_get_contents($this->_feedSamplePath)
         );
-        $this->assertEquals('The H', $feed->getAuthor());
+        $this->assertEquals(array('name'=>'The H'), $feed->getAuthor());
     }
 
     public function testGetsCopyright()
@@ -154,7 +155,7 @@ class Zend_Feed_Reader_Integration_HOnlineComAtom10Test extends PHPUnit_Framewor
             file_get_contents($this->_feedSamplePath)
         );
         $entry = $feed->current();
-        $this->assertEquals(array('The H'), $entry->getAuthors());
+        $this->assertEquals(array(array('name'=>'The H')), (array) $entry->getAuthors());
     }
 
     public function testGetsEntrySingleAuthor()
@@ -163,7 +164,7 @@ class Zend_Feed_Reader_Integration_HOnlineComAtom10Test extends PHPUnit_Framewor
             file_get_contents($this->_feedSamplePath)
         );
         $entry = $feed->current();
-        $this->assertEquals('The H', $entry->getAuthor());
+        $this->assertEquals(array('name'=>'The H'), $entry->getAuthor());
     }
 
     public function testGetsEntryDescription()
