@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StripTagsTest.php 20145 2010-01-08 15:18:56Z matthew $
+ * @version    $Id: StripTagsTest.php 21553 2010-03-18 18:49:26Z thomas $
  */
 
 // Call Zend_Filter_StripTagsTest::main() if this source file is executed directly.
@@ -40,7 +40,7 @@ require_once 'Zend/Filter/StripTags.php';
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Filter
  */
@@ -433,8 +433,8 @@ class Zend_Filter_StripTagsTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * Ensures expected behavior when comments are marked as allowed (in our 
-     * case, this should have no effect) and a comment contains tags and 
+     * Ensures expected behavior when comments are marked as allowed (in our
+     * case, this should have no effect) and a comment contains tags and
      * linebreaks
      *
      * @group ZF-8473
@@ -457,7 +457,7 @@ class Zend_Filter_StripTagsTest extends PHPUnit_Framework_TestCase
     public function testSpecifyingCommentsAllowedShouldStillStripNestedComments()
     {
         $input    = '<a> <!-- <b> <!-- <c> --> <d> --> <e>';
-        $expected = '   ';
+        $expected = '  ';
         $this->_filter->setCommentsAllowed(true);
         $this->assertEquals($expected, $this->_filter->filter($input));
     }
@@ -523,6 +523,57 @@ class Zend_Filter_StripTagsTest extends PHPUnit_Framework_TestCase
         $filtered = $this->_filter->filter($input);
         $this->assertNotContains('onclick', $filtered);
     }
+
+    /**
+     * @ZF-8828
+     */
+    public function testFilterIsoChars()
+    {
+        $input    = 'äöü<!-- a comment -->äöü';
+        $expected = 'äöüäöü';
+        $this->assertEquals($expected, $this->_filter->filter($input));
+
+        $input    = 'äöü<!-- a comment -->äöü';
+        $input    = iconv("UTF-8", "ISO-8859-1", $input);
+        $output   = $this->_filter->filter($input);
+        $this->assertFalse(empty($output));
+    }
+
+    /**
+     * @ZF-8828
+     */
+    public function testFilterIsoCharsInComment()
+    {
+        $input    = 'äöü<!--üßüßüß-->äöü';
+        $expected = 'äöüäöü';
+        $this->assertEquals($expected, $this->_filter->filter($input));
+
+        $input    = 'äöü<!-- a comment -->äöü';
+        $input    = iconv("UTF-8", "ISO-8859-1", $input);
+        $output   = $this->_filter->filter($input);
+        $this->assertFalse(empty($output));
+    }
+
+    /**
+     * @ZF-8828
+     */
+    public function testFilterSplitCommentTags()
+    {
+        $input    = 'äöü<!-->üßüßüß<-->äöü';
+        $expected = 'äöüäöü';
+        $this->assertEquals($expected, $this->_filter->filter($input));
+    }
+
+    /**
+     * @group ZF-9434
+     */
+    public function testCommentWithTagInSameLine()
+    {
+        $input    = 'test <!-- testcomment --> test <div>div-content</div>';
+        $expected = 'test  test div-content';
+        $this->assertEquals($expected, $this->_filter->filter($input));
+    }
+
 }
 
 // Call Zend_Filter_StripTagsTest::main() if this source file is executed directly.
