@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ElementTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: ElementTest.php 20705 2010-01-27 20:46:23Z thomas $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -36,6 +36,7 @@ require_once 'Zend/Form.php';
 require_once 'Zend/Form/Decorator/Abstract.php';
 require_once 'Zend/Form/Decorator/HtmlTag.php';
 require_once 'Zend/Loader/PluginLoader.php';
+require_once 'Zend/Registry.php';
 require_once 'Zend/Translate.php';
 require_once 'Zend/Validate/NotEmpty.php';
 require_once 'Zend/Validate/EmailAddress.php';
@@ -45,7 +46,7 @@ require_once 'Zend/View.php';
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Form
  */
@@ -59,6 +60,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
 
     public function setUp()
     {
+        Zend_Registry::_unsetInstance();
         Zend_Form::setDefaultTranslator(null);
 
         if (isset($this->error)) {
@@ -826,7 +828,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $messages = $this->element->getMessages();
         $found    = false;
         foreach ($messages as $key => $message) {
-            if ($key == 'stringEmpty') {
+            if ($key == 'digitsStringEmpty') {
                 $found = true;
                 break;
             }
@@ -1692,7 +1694,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
 
         $options = $this->getOptions();
         $options['validators'] = array(
-            array('notEmpty', true, array('bar')),
+            array('notEmpty', true, array(Zend_Validate_NotEmpty::ALL)),
             array('digits', true, array('bar')),
         );
         $this->element->setOptions($options);
@@ -1711,7 +1713,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $options = $this->getOptions();
         $options['validators'] = array(
             array(
-                'options'             => array('bar'),
+                'options'             => array(Zend_Validate_NotEmpty::ALL),
                 'breakChainOnFailure' => true,
                 'validator'           => 'notEmpty',
             ),
@@ -1749,12 +1751,12 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
 
         $options = $this->getOptions();
         $options['filters'] = array(
-            array('StringToUpper', array('bar' => 'baz')),
+            array('Digits', array('bar' => 'baz')),
             array('Alpha', array('foo')),
         );
         $this->element->setOptions($options);
-        $filter = $this->element->getFilter('StringToUpper');
-        $this->assertTrue($filter instanceof Zend_Filter_StringToUpper);
+        $filter = $this->element->getFilter('Digits');
+        $this->assertTrue($filter instanceof Zend_Filter_Digits);
         $filter = $this->element->getFilter('Alpha');
         $this->assertTrue($filter instanceof Zend_Filter_Alpha);
     }
@@ -1767,7 +1769,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $options['filters'] = array(
             array(
                 'options' => array('baz'),
-                'filter'  => 'StringToUpper'
+                'filter'  => 'Digits'
             ),
             array(
                 'options' => array('foo'),
@@ -1775,8 +1777,8 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
             ),
         );
         $this->element->setOptions($options);
-        $filter = $this->element->getFilter('StringToUpper');
-        $this->assertTrue($filter instanceof Zend_Filter_StringToUpper);
+        $filter = $this->element->getFilter('Digits');
+        $this->assertTrue($filter instanceof Zend_Filter_Digits);
         $filter = $this->element->getFilter('Alpha');
         $this->assertTrue($filter instanceof Zend_Filter_Alpha);
     }
@@ -1939,6 +1941,14 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $this->assertFalse($this->element->isValid('    '));
     }
 
+    public function testTranslatedLabel()
+    {
+        $this->element->setLabel('FooBar');
+        $translator = new Zend_Translate('array', array('FooBar' => 'BazBar'));
+        $this->element->setTranslator($translator);
+        $this->assertEquals('BazBar', $this->element->getLabel());
+    }
+
     // Extensions
 
     public function testInitCalledBeforeLoadDecorators()
@@ -2015,6 +2025,30 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
             $this->markTestIncomplete('Error occurs for PHP 5.1.4 on Windows');
         }
     }
+
+    /**
+     * @ZF-8882
+     */
+    public function testErrorMessagesShouldNotBeTranslatedWhenTranslatorIsDisabled()
+    {
+        $translations = array(
+            'foo' => 'Foo message',
+        );
+        $translate = new Zend_Translate('array', $translations);
+        $this->element->setTranslator($translate)
+                      ->addErrorMessage('foo')
+                      ->addValidator('Alpha');
+        $this->assertFalse($this->element->isValid(123));
+        $messages = $this->element->getMessages();
+        $this->assertEquals(1, count($messages));
+        $this->assertEquals('Foo message', array_shift($messages));
+
+        $this->element->setDisableTranslator(true);
+        $this->assertFalse($this->element->isValid(123));
+        $messages = $this->element->getMessages();
+        $this->assertEquals(1, count($messages));
+        $this->assertEquals('foo', array_shift($messages));
+    }
 }
 
 class Zend_Form_ElementTest_Decorator extends Zend_Form_Decorator_Abstract
@@ -2044,6 +2078,17 @@ class Zend_Form_ElementTest_ArrayFilter implements Zend_Filter_Interface
         }
         return (strstr($value, 'ba'));
     }
+
+    /**
+     * Check array notation for validators
+     */
+    public function testValidatorsGivenArrayKeysOnValidation()
+    {
+        $username = new Zend_Form_Element('username');
+        $username->addValidator('stringLength', true, array('min' => 5, 'max' => 20, 'ignore' => 'something'));
+        $form = new Zend_Form(array('elements' => array($username)));
+        $this->assertTrue($form->isValid(array('username' => 'abcde')));
+    }
 }
 
 if (PHPUnit_MAIN_METHOD == 'Zend_Form_ElementTest::main') {
