@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_Gdata_Calendar
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id $
  */
@@ -28,7 +28,7 @@ require_once 'Zend/Http/Client.php';
  * @category   Zend
  * @package    Zend_Gdata_Calendar
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Gdata
  * @group      Zend_Gdata_Calendar
@@ -255,6 +255,16 @@ class Zend_Gdata_Calendar_EventQueryTest extends PHPUnit_Framework_TestCase
         $this->query->resetParameters();
         $this->assertEquals("http://www.google.com/calendar/feeds/default/public/full",
                 $this->query->getQueryUrl());
+    }
 
+    public function testCanNullifyParameters()
+    {
+       $testURI = "http://www.google.com/calendar/feeds/foo%40group.calendar.google.com/private/full";
+       $this->query = new Zend_Gdata_Calendar_EventQuery($testURI);
+       $this->query->setUser(null);
+       $this->query->setVisibility(null);
+       $this->query->setProjection(null);
+       $result = $this->query->getQueryUrl();
+       $this->assertEquals($testURI, $result);
     }
 }
