@@ -15,8 +15,9 @@
  * @category   Zend
  * @package    Zend_Locale
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -37,8 +38,9 @@ require_once 'Zend/Cache.php';
  * @category   Zend
  * @package    Zend_Locale
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Locale
  */
 class Zend_LocaleTest extends PHPUnit_Framework_TestCase
 {
@@ -534,7 +536,7 @@ class Zend_LocaleTest extends PHPUnit_Framework_TestCase
 
         $char = Zend_LocaleTestHelper::getTranslationList('characters', 'de_DE');
         $this->assertEquals("[a ä b-o ö p-s ß t u ü v-z]", $char['characters']);
-        $this->assertEquals("[á à ă â å ä ā æ ç é è ĕ ê ë ē í ì ĭ î ï ī ñ ó ò ŏ ô ö ø ō œ ß ú ù ŭ û ü ū ÿ]", $char['auxiliary']);
+        $this->assertEquals("[á à ă â å ā æ ç é è ĕ ê ë ē í ì ĭ î ï ī ñ ó ò ŏ ô ø ō œ ú ù ŭ û ū ÿ]", $char['auxiliary']);
         $this->assertEquals("[a-z]", $char['currencySymbol']);
 
         $char = Zend_LocaleTestHelper::getTranslationList('characters', 'en');
@@ -579,7 +581,7 @@ class Zend_LocaleTest extends PHPUnit_Framework_TestCase
         try {
             $this->assertTrue(is_array(Zend_LocaleTestHelper::getQuestion('environment')));
         } catch (Zend_Locale_Exception $e) {
-            $this->assertContains('Autodetection', $e->getMessage());
+            $this->assertContains('ocale', $e->getMessage());
         }
     }
 
@@ -793,7 +795,7 @@ class Zend_LocaleTest extends PHPUnit_Framework_TestCase
         $locale = $value->toString();
         $this->assertTrue(!empty($locale));
 
-        $this->assertTrue(Zend_LocaleTestHelper::isLocale(null));
+        $this->assertFalse(Zend_LocaleTestHelper::isLocale(null));
 
         $value = new Zend_LocaleTestHelper(0);
         $value = $value->toString();
@@ -814,6 +816,26 @@ class Zend_LocaleTest extends PHPUnit_Framework_TestCase
 
         $locale = new Zend_LocaleTestHelper('de_Latn_DE');
         $this->assertEquals('de_DE', $locale->toString());
+
+        $this->assertEquals('fr_FR', Zend_Locale::findLocale('fr-Arab-FR'));
+    }
+
+    /**
+     * test SunLocales
+     * expected boolean
+     */
+    public function testSunLocale()
+    {
+        $this->assertTrue(Zend_LocaleTestHelper::isLocale('de_DE.utf8'));
+        $this->assertFalse(Zend_LocaleTestHelper::isLocale('de.utf8.DE'));
+    }
+
+    /**
+     * @ZF-8030
+     */
+    public function testFailedLocaleOnPreTranslations()
+    {
+        $this->assertEquals('Andorra', Zend_LocaleTestHelper::getTranslation('AD', 'country', 'gl_GL'));
     }
 
     /**
