@@ -15,13 +15,12 @@
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: LogTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: LogTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
-/** PHPUnit_Framework_TestCase */
-require_once 'PHPUnit/Framework/TestCase.php';
+require_once dirname(__FILE__) . '/../../TestHelper.php';
 
 /** Zend_Log */
 require_once 'Zend/Log.php';
@@ -29,11 +28,14 @@ require_once 'Zend/Log.php';
 /** Zend_Log_Writer_Mock */
 require_once 'Zend/Log/Writer/Mock.php';
 
+/** Zend_Log_Writer_Stream */
+require_once 'Zend/Log/Writer/Stream.php';
+
 /**
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Log
  */
@@ -50,7 +52,7 @@ class Zend_Log_LogTest extends PHPUnit_Framework_TestCase
     public function testWriterCanBeAddedWithConstructor()
     {
         $logger = new Zend_Log($this->writer);
-        $logger->log($message = 'message-to-long', Zend_Log::INFO);
+        $logger->log($message = 'message-to-log', Zend_Log::INFO);
 
         rewind($this->log);
         $this->assertContains($message, stream_get_contents($this->log));
@@ -201,4 +203,88 @@ class Zend_Log_LogTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(array_key_exists($field, $event));
         $this->assertEquals($value, $event[$field]);
     }
+
+    /**
+     * @group ZF-8491
+     */
+    public function testLogAcceptsExtrasParameterAsArrayAndPushesIntoEvent()
+    {
+        $logger = new Zend_Log($mock = new Zend_Log_Writer_Mock);
+        $logger->info('foo', array('content' => 'nonesuch'));
+        $event = array_shift($mock->events);
+        $this->assertContains('content', array_keys($event));
+        $this->assertEquals('nonesuch', $event['content']);
+    }
+
+    /**
+     * @group ZF-8491
+     */
+    public function testLogNumericKeysInExtrasArrayArePassedToInfoKeyOfEvent()
+    {
+        $logger = new Zend_Log($mock = new Zend_Log_Writer_Mock);
+        $logger->info('foo', array('content' => 'nonesuch', 'bar'));
+        $event = array_shift($mock->events);
+        $this->assertContains('content', array_keys($event));
+        $this->assertContains('info', array_keys($event));
+        $this->assertContains('bar', $event['info']);
+    }
+
+    /**
+     * @group ZF-8491
+     */
+    public function testLogAcceptsExtrasParameterAsScalarAndAddsAsInfoKeyToEvent()
+    {
+        $logger = new Zend_Log($mock = new Zend_Log_Writer_Mock);
+        $logger->info('foo', 'nonesuch');
+        $event = array_shift($mock->events);
+        $this->assertContains('info', array_keys($event));
+        $info = $event['info'];
+        $this->assertContains('nonesuch', $info);
+    }
+    
+    // Factory
+
+    public function testLogConstructFromConfigStream() 
+    {
+        $cfg = array('log' => array('memory' => array(
+            'writerName'      => "Stream", 
+            'writerNamespace' => "Zend_Log_Writer", 
+            'writerParams'    => array(
+                'stream'      => "php://memory"
+            )        
+        )));
+
+        $logger = Zend_Log::factory($cfg['log']);
+        $this->assertTrue($logger instanceof Zend_Log);
+    }
+
+    public function testLogConstructFromConfigStreamAndFilter() 
+    {
+        $cfg = array('log' => array('memory' => array(
+            'writerName'      => "Stream", 
+            'writerNamespace' => "Zend_Log_Writer", 
+            'writerParams'    => array(
+                'stream'      => "php://memory"
+            ), 
+            'filterName'   => "Priority", 
+            'filterParams' => array(
+                'priority' => "Zend_Log::CRIT", 
+                'operator' => "<="
+             ),        
+        )));
+
+        $logger = Zend_Log::factory($cfg['log']);
+        $this->assertTrue($logger instanceof Zend_Log);
+    }
+
+    public function testFactoryUsesNameAndNamespaceWithoutModifications() 
+    {
+        $cfg = array('log' => array('memory' => array(
+            'writerName'      => "ZendMonitor", 
+            'writerNamespace' => "Zend_Log_Writer", 
+        )));
+
+        $logger = Zend_Log::factory($cfg['log']);
+        $this->assertTrue($logger instanceof Zend_Log);
+    }
 }
