@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StreamTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: StreamTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 /** PHPUnit_Framework_TestCase */
@@ -30,7 +30,7 @@ require_once 'Zend/Log/Writer/Stream.php';
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Log
  */
@@ -145,4 +145,32 @@ class Zend_Log_Writer_StreamTest extends PHPUnit_Framework_TestCase
 
         $this->assertContains($expected, $contents);
     }
+    
+    public function testFactoryStream()
+    {
+        $cfg = array('log' => array('memory' => array(
+            'writerName'   => "Mock",
+            'writerParams' => array(
+                'stream' => 'php://memory',
+                'mode'   => 'a'
+            )
+        )));
+
+        $logger = Zend_Log::factory($cfg['log']);
+        $this->assertTrue($logger instanceof Zend_Log);
+    }
+    
+    public function testFactoryUrl()
+    {
+        $cfg = array('log' => array('memory' => array(
+            'writerName'   => "Mock",
+            'writerParams' => array(
+                'url'  => 'http://localhost',
+                'mode' => 'a'
+            )
+        )));
+
+        $logger = Zend_Log::factory($cfg['log']);
+        $this->assertTrue($logger instanceof Zend_Log);
+    }
 }
