@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MemoryManagerTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: MemoryManagerTest.php 20805 2010-02-01 15:52:15Z alexander $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -36,7 +36,7 @@ require_once 'Zend/Memory.php';
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Memory
  */
@@ -89,6 +89,18 @@ class Zend_Memory_MemoryManagerTest extends PHPUnit_Framework_TestCase
     }
 
 
+    /**
+     * tests the Memory Manager backends naming processing
+     *
+     * @group ZF-9023
+     */
+    public function testBackendNamingProcessing()
+    {
+        /** 'File' backend */
+        $backendOptions = array('cache_dir' => $this->cacheDir); // Directory where to put the cache files
+        $memoryManager = Zend_Memory::factory('fIlE', $backendOptions);
+    }
+
     /**
      * tests the Memory Manager settings
      */
