@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Paginator
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: IteratorTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: IteratorTest.php 21151 2010-02-23 16:34:14Z matthew $
  */
 
 /**
@@ -34,7 +34,7 @@ require_once 'PHPUnit/Framework/TestCase.php';
  * @category   Zend
  * @package    Zend_Paginator
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Paginator
  */
@@ -117,4 +117,24 @@ class Zend_Paginator_Adapter_IteratorTest extends PHPUnit_Framework_TestCase
             $this->fail('Empty iterator caused in an OutOfBoundsException');
         }
     }
+
+    /**
+     * @group ZF-8084
+     */
+    public function testGetItemsSerializable() {
+        $items = $this->_adapter->getItems(0, 1);
+        $innerIterator = $items->getInnerIterator();
+        $items = unserialize(serialize($items));
+        $this->assertTrue( ($items->getInnerIterator() == $innerIterator), 'getItems has to be serializable to use caching');
+    }
+
+    /**
+     * @group ZF-4151
+     */
+    public function testEmptySet() {
+        $iterator = new ArrayIterator(array());
+        $this->_adapter = new Zend_Paginator_Adapter_Iterator($iterator);
+        $actual = $this->_adapter->getItems(0, 10);
+        $this->assertEquals(array(), $actual);
+    }
 }
