@@ -15,11 +15,16 @@
  * @category   Zend
  * @package    Zend_Paginator
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: NullTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: NullTest.php 21151 2010-02-23 16:34:14Z matthew $
  */
 
+/**
+ * @see Zend_Paginator
+ */
+require_once 'Zend/Paginator.php';
+
 /**
  * @see Zend_Paginator_Adapter_Null
  */
@@ -34,8 +39,9 @@ require_once 'PHPUnit/Framework/TestCase.php';
  * @category   Zend
  * @package    Zend_Paginator
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Paginator
  */
 class Zend_Paginator_Adapter_NullTest extends PHPUnit_Framework_TestCase
 {
@@ -71,4 +77,46 @@ class Zend_Paginator_Adapter_NullTest extends PHPUnit_Framework_TestCase
     {
         $this->assertEquals(101, $this->_adapter->count());
     }
-}
\ No newline at end of file
+
+    /**
+     * @group ZF-3873
+     */
+    public function testAdapterReturnsCorrectValues()
+    {
+        $paginator = Zend_Paginator::factory(2);
+        $paginator->setCurrentPageNumber(1);
+        $paginator->setItemCountPerPage(5);
+
+        $pages = $paginator->getPages();
+
+        $this->assertEquals(2, $pages->currentItemCount);
+        $this->assertEquals(2, $pages->lastItemNumber);
+
+        $paginator = Zend_Paginator::factory(19);
+        $paginator->setCurrentPageNumber(4);
+        $paginator->setItemCountPerPage(5);
+
+        $pages = $paginator->getPages();
+
+        $this->assertEquals(4, $pages->currentItemCount);
+        $this->assertEquals(19, $pages->lastItemNumber);
+    }
+
+    /**
+     * @group ZF-4151
+     */
+    public function testEmptySet() {
+        $this->_adapter = new Zend_Paginator_Adapter_Null(0);
+        $actual = $this->_adapter->getItems(0, 10);
+        $this->assertEquals(array(), $actual);
+    }
+    
+    /**
+     * Verify that the fix for ZF-4151 doesn't create an OBO error
+     */
+    public function testSetOfOne() {
+        $this->_adapter = new Zend_Paginator_Adapter_Null(1);
+        $actual = $this->_adapter->getItems(0, 10);
+        $this->assertEquals(array_fill(0, 1, null), $actual);
+    }
+}
