@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Paginator
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: PaginatorTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: PaginatorTest.php 20444 2010-01-20 16:04:13Z ralph $
  */
 
 // Call Zend_PaginatorTest::main() if this source file is executed directly.
@@ -94,7 +94,7 @@ require_once 'Zend/Filter/Callback.php';
  * @category   Zend
  * @package    Zend_Paginator
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Paginator
  */
@@ -166,7 +166,7 @@ class Zend_PaginatorTest extends PHPUnit_Framework_TestCase
 
     protected function _getTmpDir()
     {
-        $tmpDir = sys_get_temp_dir() . '/zend_paginator';
+        $tmpDir = rtrim(sys_get_temp_dir(), '/\\') . DIRECTORY_SEPARATOR . 'zend_paginator';
         if (file_exists($tmpDir)) {
             $this->_rmDirRecursive($tmpDir);
         }
@@ -185,6 +185,7 @@ class Zend_PaginatorTest extends PHPUnit_Framework_TestCase
                 $this->_rmDirRecursive($file->getPathname());
             }
         }
+        unset($file, $dir); // required on windows to remove file handle
         if (!rmdir($path)) {
             throw new Exception('Unable to remove temporary directory ' . $path
                                 . '; perhaps it has a nested structure?');
@@ -881,6 +882,7 @@ class Zend_PaginatorTest extends PHPUnit_Framework_TestCase
 
         $this->_restorePaginatorDefaults();
     }
+
     /**
      * @group ZF-7207
      */
@@ -890,6 +892,16 @@ class Zend_PaginatorTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(2, $paginator->count());
     }
 
+    /**
+     * @group ZF-5427
+     */
+    public function testNegativeItemNumbers()
+    {
+        $this->assertEquals(10, $this->_paginator->getItem(-1, 1));
+        $this->assertEquals(9, $this->_paginator->getItem(-2, 1));
+        $this->assertEquals(101, $this->_paginator->getItem(-1, -1));
+    }
+
     /**
      * @group ZF-7602
      */
