@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Rest
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ServerTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: ServerTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 // Call Zend_Rest_ServerTest::main() if this source file is executed directly.
@@ -38,7 +38,7 @@ require_once 'Zend/Rest/Server.php';
  * @category   Zend
  * @package    Zend_Rest
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Rest
  * @group      Zend_Rest_Server
@@ -525,16 +525,18 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-1949
+     * @see ZF-7977
      * @group ZF-1949
+     * @group ZF-7977
      */
     public function testMissingArgumentsShouldResultInFaultResponse()
     {
         $server = new Zend_Rest_Server();
         $server->setClass('Zend_Rest_Server_Test');
         ob_start();
-        $server->handle(array('method' => 'testFunc6', 'arg1' => "Davey"));
+        $server->handle(array('method' => 'testFunc6', 'arg1' => 'Davey'));
         $result = ob_get_clean();
-        $this->assertRegexp('#<message>Invalid Method Call to(.*?)(Requires).*?(given).*?(</message>)#', $result);
+        $this->assertRegexp('#<message>Invalid Method Call to(.*?)(Missing argument\(s\): ).*?(</message>)#', $result);
         $this->assertContains('<status>failed</status>', $result);
     }
 
